summaryrefslogtreecommitdiff
path: root/lisp
diff options
context:
space:
mode:
Diffstat (limited to 'lisp')
-rw-r--r--lisp/shell.el6
1 files changed, 3 insertions, 3 deletions
diff --git a/lisp/shell.el b/lisp/shell.el
index 1f69e426d91..0c405026e65 100644
--- a/lisp/shell.el
+++ b/lisp/shell.el
@@ -135,7 +135,7 @@
;;; cmushell-mode-map, that sort of thing. All the names have been carefully
;;; chosen so that shell.el and cmushell.el won't tromp on each other.
;;; Customisation and Buffer Variables
;;; ===========================================================================
;;;
@@ -219,7 +219,7 @@ M-x dirs queries the shell and resyncs Emacs' idea of what the current
M-x dirtrack-toggle turns directory tracking on and off.
\\{shell-mode-map}
-Customisation: Entry to this mode runs the hooks on comint-mode-hook and
+Customization: Entry to this mode runs the hooks on comint-mode-hook and
shell-mode-hook (in that order).
Variables shell-cd-regexp, shell-pushd-regexp and shell-popd-regexp are used
@@ -548,7 +548,7 @@ command again."
;;; Do the user's customisation...
;;;===============================
(defvar shell-load-hook nil
"This hook is run when shell is loaded in.
@@ -135,7 +135,7 @@
;;; cmushell-mode-map, that sort of thing. All the names have been carefully
;;; chosen so that shell.el and cmushell.el won't tromp on each other.
-;;; Customisation and Buffer Variables
+;;; Customization and Buffer Variables
;;; ===========================================================================
;;;
@@ -548,7 +548,7 @@ command again."
Variables shell-cd-regexp, shell-pushd-regexp and shell-popd-regexp are used
-;;; Do the user's customisation...
+;;; Do the user's customization...
;;;===============================
(defvar shell-load-hook nil